# ssh-assist

A simple CLI to help with my daily need.

most of the features that it implements might already exists in ssh or can be done via the ssh config file.
But me being me, is too lazy to look it up. I just want to do things my way :)
